@@ -26,18 +26,18 @@ class AliyunProvider(BaseProvider):
         self.credentials = kwargs['credentials']
         self.account_id = self.credentials.caller_details['AccountId']
 
-        super(AliyunProvider, self).__init__(report_dir, timestamp, services, skipped_services)
+        super().__init__(report_dir, timestamp, services, skipped_services)
 
     def get_report_name(self):
         """
         Returns the name of the report using the provider's configuration
         """
         if self.account_id:
-            return 'aliyun-{}'.format(self.account_id)
+            return f'aliyun-{self.account_id}'
         else:
             return 'aliyun'
 
     def preprocessing(self, ip_ranges=None, ip_ranges_name_key=None):
 
-        super(AliyunProvider, self).preprocessing()
+        super().preprocessing()
 
