@@ -156,17 +156,23 @@ class AWSProvider(BaseProvider):
 
     def _check_ec2_zone_distribution(self):
         regions = self.services['ec2']['regions'].values()
-        self.services['ec2']['number_of_regions_with_instances'] = sum(
-            r['instances_count'] > 0 for r in regions)
+        self.services['ec2']['number_of_regions_with_instances'] = sum(r['instances_count'] > 0 for r in regions)
+
+        for regions in self.services['ec2']['regions'].values():
+            instances_availability_zones = set()
+            for vpcs in regions['vpcs'].values():
+                for instance in vpcs['instances'].values():
+                    instances_availability_zones.add(instance.get('availability_zone'))
+            regions['instances_availability_zones'] = len(instances_availability_zones)
 
     def _add_last_snapshot_date_to_ec2_volumes(self):
         for region in self.services['ec2']['regions'].values():
             for volumeId, volume in region.get('volumes').items():
                 completed_snapshots = [s for s in region['snapshots'].values() if
-                                       s['VolumeId'] == volumeId and s['State'] == 'completed']
+                                       s['volume_id'] == volumeId and s['state'] == 'completed']
                 sorted_snapshots = sorted(
-                    completed_snapshots, key=lambda s: s['StartTime'], reverse=True)
-                volume['LastSnapshotDate'] = sorted_snapshots[0]['StartTime'] if len(
+                    completed_snapshots, key=lambda s: s['start_time'], reverse=True)
+                volume['LastSnapshotDate'] = sorted_snapshots[0]['start_time'] if len(
                     sorted_snapshots) > 0 else None
 
     def add_security_group_name_to_ec2_grants_callback(self, current_config, path, current_path, ec2_grant,
