@@ -4,7 +4,7 @@ from ScoutSuite.providers.aws.facade.base import AWSFacade
 
 class AmazonMachineImages(AWSResources):
     def __init__(self, facade: AWSFacade, region: str):
-        super(AmazonMachineImages, self).__init__(facade)
+        super().__init__(facade)
         self.region = region
 
     async def fetch_all(self):
@@ -16,4 +16,7 @@ class AmazonMachineImages(AWSResources):
     def _parse_image(self, raw_image):
         raw_image['id'] = raw_image.get('ImageId')
         raw_image['name'] = raw_image.get('Name')
+        raw_image['arn'] = 'arn:aws:ec2:{}:{}:ami/{}'.format(self.region,
+                                                            raw_image.get('OwnerId'),
+                                                            raw_image.get('ImageId'))
         return raw_image['id'], raw_image
