@@ -4,7 +4,7 @@ from ScoutSuite.providers.aws.resources.base import AWSResources
 
 class Clusters(AWSResources):
     def __init__(self, facade: AWSFacade, region: str, vpc: str):
-        super(Clusters, self).__init__(facade)
+        super().__init__(facade)
         self.region = region
         self.vpc = vpc
 
@@ -16,4 +16,7 @@ class Clusters(AWSResources):
 
     def _parse_cluster(self, raw_cluster):
         raw_cluster['name'] = raw_cluster.pop('CacheClusterId')
+        raw_cluster['arn'] = 'arn:aws:elasticache:{}:{}:cluster/{}'.format(self.region,
+                                                                             self.facade.owner_id,
+                                                                             raw_cluster.get('name'))
         return raw_cluster['name'], raw_cluster
