@@ -1,6 +1,8 @@
 from azure.graphrbac import GraphRbacManagementClient
+
 from ScoutSuite.core.console import print_exception
 from ScoutSuite.providers.utils import run_concurrently
+from ScoutSuite.utils import get_user_agent
 
 
 class AADFacade:
@@ -9,8 +11,10 @@ class AADFacade:
         self.credentials = credentials
 
     def get_client(self):
-        return GraphRbacManagementClient(self.credentials.get_credentials('aad_graph'),
+        client = GraphRbacManagementClient(self.credentials.get_credentials('aad_graph'),
                                          tenant_id=self.credentials.get_tenant_id())
+        client._client.config.add_user_agent(get_user_agent())
+        return client
 
     async def get_users(self):
         try:
@@ -22,21 +26,21 @@ class AADFacade:
             ])
             return await run_concurrently(lambda: list(self.get_client().users.list(filter=user_filter)))
         except Exception as e:
-            print_exception('Failed to retrieve users: {}'.format(e))
+            print_exception(f'Failed to retrieve users: {e}')
             return []
 
     async def get_user(self, user_id):
         try:
             return await run_concurrently(lambda: self.get_client().users.get(user_id))
         except Exception as e:
-            print_exception('Failed to retrieve user {}: {}'.format(user_id, e))
-            return []
+            print_exception(f'Failed to retrieve user {user_id}: {e}')
+            return None
 
     async def get_groups(self):
         try:
             return await run_concurrently(lambda: list(self.get_client().groups.list()))
         except Exception as e:
-            print_exception('Failed to retrieve groups: {}'.format(e))
+            print_exception(f'Failed to retrieve groups: {e}')
             return []
 
     async def get_user_groups(self, user_id):
@@ -46,19 +50,19 @@ class AADFacade:
                                                           security_enabled_only=False))
                                           )
         except Exception as e:
-            print_exception('Failed to retrieve user\'s groups: {}'.format(e))
+            print_exception(f'Failed to retrieve user\'s groups: {e}')
             return []
 
     async def get_service_principals(self):
         try:
             return await run_concurrently(lambda: list(self.get_client().service_principals.list()))
         except Exception as e:
-            print_exception('Failed to retrieve service principals: {}'.format(e))
+            print_exception(f'Failed to retrieve service principals: {e}')
             return []
 
     async def get_applications(self):
         try:
             return await run_concurrently(lambda: list(self.get_client().applications.list()))
         except Exception as e:
-            print_exception('Failed to retrieve applications: {}'.format(e))
+            print_exception(f'Failed to retrieve applications: {e}')
             return []
