@@ -2,6 +2,7 @@ from azure.mgmt.keyvault import KeyVaultManagementClient
 
 from ScoutSuite.core.console import print_exception
 from ScoutSuite.providers.utils import run_concurrently
+from ScoutSuite.utils import get_user_agent
 
 
 class KeyVaultFacade:
@@ -10,8 +11,10 @@ class KeyVaultFacade:
         self.credentials = credentials
 
     def get_client(self, subscription_id: str):
-        return KeyVaultManagementClient(self.credentials.get_credentials('arm'),
+        client = KeyVaultManagementClient(self.credentials.get_credentials('arm'),
                                         subscription_id=subscription_id)
+        client._client.config.add_user_agent(get_user_agent())
+        return client
 
     async def get_key_vaults(self, subscription_id: str):
         try:
@@ -19,5 +22,5 @@ class KeyVaultFacade:
             return await run_concurrently(
                 lambda: list(client.vaults.list_by_subscription()))
         except Exception as e:
-            print_exception('Failed to retrieve key vaults: {}'.format(e))
+            print_exception(f'Failed to retrieve key vaults: {e}')
             return []
