@@ -1,12 +1,13 @@
 from ScoutSuite.providers.azure.facade.base import AzureFacade
 from ScoutSuite.providers.azure.resources.base import AzureResources
 from ScoutSuite.providers.utils import get_non_provider_id
+from ScoutSuite.providers.azure.utils import get_resource_group_name
 
 
 class Vaults(AzureResources):
 
     def __init__(self, facade: AzureFacade, subscription_id: str):
-        super(Vaults, self).__init__(facade)
+        super().__init__(facade)
         self.subscription_id = subscription_id
 
     async def fetch_all(self):
@@ -21,7 +22,11 @@ class Vaults(AzureResources):
         vault['type'] = raw_vault.type
         vault['location'] = raw_vault.location
         vault['additional_properties'] = raw_vault.additional_properties
-        vault['tags'] = raw_vault.tags
+        if raw_vault.tags is not None:
+            vault['tags'] = ["{}:{}".format(key, value) for key, value in  raw_vault.tags.items()]
+        else:
+            vault['tags'] = []
+        vault['resource_group_name'] = get_resource_group_name(raw_vault.id)
         vault['properties'] = raw_vault.properties
         vault['public_access_allowed'] = self._is_public_access_allowed(raw_vault)
         return vault['id'], vault
