@@ -6,7 +6,7 @@ class ReplicationLinks(AzureResources):
 
     def __init__(self, facade: AzureFacade, resource_group_name: str, server_name: str, database_name: str,
                  subscription_id: str):
-        super(ReplicationLinks, self).__init__(facade)
+        super().__init__(facade)
         self.resource_group_name = resource_group_name
         self.server_name = server_name
         self.database_name = database_name
