@@ -5,34 +5,34 @@ from ScoutSuite.providers.utils import run_concurrently
 
 class IAMFacade(GCPBaseFacade):
     def __init__(self):
-        super(IAMFacade, self).__init__('iam', 'v1')
+        super().__init__('iam', 'v1')
 
     async def get_service_accounts(self, project_id: str):
         try:
-            name = 'projects/{}'.format(project_id)
+            name = f'projects/{project_id}'
             iam_client = self._get_client()
             request = iam_client.projects().serviceAccounts().list(name=name)
             service_accounts_group = iam_client.projects().serviceAccounts()
             return await GCPFacadeUtils.get_all('accounts', request, service_accounts_group)
         except Exception as e:
-            print_exception('Failed to retrieve service accounts: {}'.format(e))
+            print_exception(f'Failed to retrieve service accounts: {e}')
             return []
 
     async def get_service_account_bindings(self, project_id: str, service_account_email: str):
         try:
-            resource = 'projects/{}/serviceAccounts/{}'.format(project_id, service_account_email)
+            resource = f'projects/{project_id}/serviceAccounts/{service_account_email}'
             iam_client = self._get_client()
             response = await run_concurrently(
                     lambda: iam_client.projects().serviceAccounts().getIamPolicy(resource=resource).execute()
             )
             return response.get('bindings', [])
         except Exception as e:
-            print_exception('Failed to retrieve service account IAM policy bindings: {}'.format(e))
+            print_exception(f'Failed to retrieve service account IAM policy bindings: {e}')
             return []
 
     async def get_service_account_keys(self, project_id: str, service_account_email: str, key_types: list=[]):
         try:
-            name = 'projects/{}/serviceAccounts/{}'.format(project_id, service_account_email)
+            name = f'projects/{project_id}/serviceAccounts/{service_account_email}'
             iam_client = self._get_client()
             response = await run_concurrently(
                     lambda: iam_client.projects().serviceAccounts().keys().list(name=name,
@@ -40,7 +40,7 @@ class IAMFacade(GCPBaseFacade):
             )
             return response.get('keys', [])
         except Exception as e:
-            print_exception('Failed to retrieve service account keys: {}'.format(e))
+            print_exception(f'Failed to retrieve service account keys: {e}')
             return []
 
     async def get_service_account_key(self, key_name: str):
@@ -52,7 +52,7 @@ class IAMFacade(GCPBaseFacade):
             )
             return response
         except Exception as e:
-            print_exception('Failed to retrieve service account keys: {}'.format(e))
+            print_exception(f'Failed to retrieve service account keys: {e}')
             return []
 
     async def get_role_definition(self, role: str):
@@ -68,5 +68,5 @@ class IAMFacade(GCPBaseFacade):
                 )
             return response
         except Exception as e:
-            print_exception('Failed to retrieve IAM role definition: {}'.format(e))
+            print_exception(f'Failed to retrieve IAM role definition: {e}')
             return {}
