@@ -4,7 +4,7 @@ from ScoutSuite.providers.gcp.facade.base import GCPFacade
 
 class Networks(Resources):
     def __init__(self, facade: GCPFacade, project_id: str):
-        super(Networks, self).__init__(facade)
+        super().__init__(facade)
         self.project_id = project_id
 
     async def fetch_all(self):
@@ -20,10 +20,12 @@ class Networks(Resources):
         network_dict['name'] = raw_network['name']
         network_dict['description'] = self._get_description(raw_network)
         network_dict['creation_timestamp'] = raw_network['creationTimestamp']
-        network_dict['network_url'] = raw_network['selfLink']
-        network_dict['subnetwork_urls'] = raw_network.get('subnetworks', None)
         network_dict['auto_subnet'] = raw_network.get('autoCreateSubnetworks', None)
         network_dict['routing_config'] = raw_network['routingConfig']
+
+        network_dict['network_url'] = raw_network['selfLink']
+        network_dict['subnetwork_urls'] = raw_network.get('subnetworks', None)
+
         return network_dict['id'], network_dict
 
     def _get_description(self, raw_network):
